@@ -13,7 +13,7 @@ from marshmallow import ValidationError
 from . import analyze, archive, configuration, interactive, manager, reporting
 from . import resources as plotman_resources
 from .analyze.report import analyze
-from .api import start_master_api_node, PostDat
+from .query.api import start_master_api_node, PostDat
 from .clockwork import MintJ
 from .configuration import PlotmanConfig
 from .farmplot import FarmPlot
@@ -109,6 +109,8 @@ def plotting(cfg: PlotmanConfig):
             if cfg.apis.target is not "":
                 PostDat(minp.GenStatus(minp.LsJobs), cfg)
 
+            minp.SpaceManagement()
+
         except ValidationError as te:
             print('got ConfigurationException from io', te)
             continue
